#[non_exhaustive]pub enum CreateKeySigningKeyError {
ConcurrentModification(ConcurrentModification),
InvalidArgument(InvalidArgument),
InvalidInput(InvalidInput),
InvalidKeySigningKeyName(InvalidKeySigningKeyName),
InvalidKeySigningKeyStatus(InvalidKeySigningKeyStatus),
InvalidKmsArn(InvalidKmsArn),
InvalidSigningStatus(InvalidSigningStatus),
KeySigningKeyAlreadyExists(KeySigningKeyAlreadyExists),
NoSuchHostedZone(NoSuchHostedZone),
TooManyKeySigningKeys(TooManyKeySigningKeys),
Unhandled(Unhandled),
}Expand description
Error type for the CreateKeySigningKeyError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConcurrentModification(ConcurrentModification)
Another user submitted a request to create, update, or delete the object at the same time that you did. Retry the request.
InvalidArgument(InvalidArgument)
Parameter name is not valid.
InvalidInput(InvalidInput)
The input is not valid.
InvalidKeySigningKeyName(InvalidKeySigningKeyName)
The key-signing key (KSK) name that you specified isn't a valid name.
InvalidKeySigningKeyStatus(InvalidKeySigningKeyStatus)
The key-signing key (KSK) status isn't valid or another KSK has the status INTERNAL_FAILURE.
InvalidKmsArn(InvalidKmsArn)
The KeyManagementServiceArn that you specified isn't valid to use with DNSSEC signing.
InvalidSigningStatus(InvalidSigningStatus)
Your hosted zone status isn't valid for this operation. In the hosted zone, change the status to enable DNSSEC or disable DNSSEC.
KeySigningKeyAlreadyExists(KeySigningKeyAlreadyExists)
You've already created a key-signing key (KSK) with this name or with the same customer managed key ARN.
NoSuchHostedZone(NoSuchHostedZone)
No hosted zone exists with the ID that you specified.
TooManyKeySigningKeys(TooManyKeySigningKeys)
You've reached the limit for the number of key-signing keys (KSKs). Remove at least one KSK, and then try again.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateKeySigningKeyError
impl CreateKeySigningKeyError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateKeySigningKeyError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateKeySigningKeyError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_concurrent_modification(&self) -> bool
pub fn is_concurrent_modification(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::ConcurrentModification.
Sourcepub fn is_invalid_argument(&self) -> bool
pub fn is_invalid_argument(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::InvalidArgument.
Sourcepub fn is_invalid_input(&self) -> bool
pub fn is_invalid_input(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::InvalidInput.
Sourcepub fn is_invalid_key_signing_key_name(&self) -> bool
pub fn is_invalid_key_signing_key_name(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::InvalidKeySigningKeyName.
Sourcepub fn is_invalid_key_signing_key_status(&self) -> bool
pub fn is_invalid_key_signing_key_status(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::InvalidKeySigningKeyStatus.
Sourcepub fn is_invalid_kms_arn(&self) -> bool
pub fn is_invalid_kms_arn(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::InvalidKmsArn.
Sourcepub fn is_invalid_signing_status(&self) -> bool
pub fn is_invalid_signing_status(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::InvalidSigningStatus.
Sourcepub fn is_key_signing_key_already_exists(&self) -> bool
pub fn is_key_signing_key_already_exists(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::KeySigningKeyAlreadyExists.
Sourcepub fn is_no_such_hosted_zone(&self) -> bool
pub fn is_no_such_hosted_zone(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::NoSuchHostedZone.
Sourcepub fn is_too_many_key_signing_keys(&self) -> bool
pub fn is_too_many_key_signing_keys(&self) -> bool
Returns true if the error kind is CreateKeySigningKeyError::TooManyKeySigningKeys.