CreateKeySigningKeyInput

Struct CreateKeySigningKeyInput 

#[non_exhaustive]
pub struct CreateKeySigningKeyInput { pub caller_reference: Option<String>, pub hosted_zone_id: Option<String>, pub key_management_service_arn: Option<String>, pub name: Option<String>, pub status: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
caller_reference: Option<String>

A unique string that identifies the request.

hosted_zone_id: Option<String>

The unique string (ID) used to identify a hosted zone.

key_management_service_arn: Option<String>

The Amazon resource name (ARN) for a customer managed key in Key Management Service (KMS). The KeyManagementServiceArn must be unique for each key-signing key (KSK) in a single hosted zone. To see an example of KeyManagementServiceArn that grants the correct permissions for DNSSEC, scroll down to Example.

You must configure the customer managed customer managed key as follows:

Status

Enabled

Key spec

ECC_NIST_P256

Key usage

Sign and verify

Key policy

The key policy must give permission for the following actions:

  • DescribeKey

  • GetPublicKey

  • Sign

The key policy must also include the Amazon Route 53 service in the principal for your account. Specify the following:

  • "Service": "dnssec-route53.amazonaws.com"

For more information about working with a customer managed key in KMS, see Key Management Service concepts.

name: Option<String>

A string used to identify a key-signing key (KSK). Name can include numbers, letters, and underscores (_). Name must be unique for each key-signing key in the same hosted zone.

status: Option<String>

A string specifying the initial status of the key-signing key (KSK). You can set the value to ACTIVE or INACTIVE.

Implementations

Source

impl CreateKeySigningKeyInput

pub fn caller_reference(&self) -> Option<&str>

A unique string that identifies the request.

pub fn hosted_zone_id(&self) -> Option<&str>

The unique string (ID) used to identify a hosted zone.

pub fn key_management_service_arn(&self) -> Option<&str>

The Amazon resource name (ARN) for a customer managed key in Key Management Service (KMS). The KeyManagementServiceArn must be unique for each key-signing key (KSK) in a single hosted zone. To see an example of KeyManagementServiceArn that grants the correct permissions for DNSSEC, scroll down to Example.

You must configure the customer managed customer managed key as follows:

Status

Enabled

Key spec

ECC_NIST_P256

Key usage

Sign and verify

Key policy

The key policy must give permission for the following actions:

  • DescribeKey

  • GetPublicKey

  • Sign

The key policy must also include the Amazon Route 53 service in the principal for your account. Specify the following:

  • "Service": "dnssec-route53.amazonaws.com"

For more information about working with a customer managed key in KMS, see Key Management Service concepts.

pub fn name(&self) -> Option<&str>

A string used to identify a key-signing key (KSK). Name can include numbers, letters, and underscores (_). Name must be unique for each key-signing key in the same hosted zone.

pub fn status(&self) -> Option<&str>

A string specifying the initial status of the key-signing key (KSK). You can set the value to ACTIVE or INACTIVE.

Source

impl CreateKeySigningKeyInput

pub fn builder() -> CreateKeySigningKeyInputBuilder

Creates a new builder-style object to manufacture CreateKeySigningKeyInput.