KeySigningKey

Struct KeySigningKey 

#[non_exhaustive]
pub struct KeySigningKey {
Show 16 fields pub name: Option<String>, pub kms_arn: Option<String>, pub flag: i32, pub signing_algorithm_mnemonic: Option<String>, pub signing_algorithm_type: i32, pub digest_algorithm_mnemonic: Option<String>, pub digest_algorithm_type: i32, pub key_tag: i32, pub digest_value: Option<String>, pub public_key: Option<String>, pub ds_record: Option<String>, pub dnskey_record: Option<String>, pub status: Option<String>, pub status_message: Option<String>, pub created_date: Option<DateTime>, pub last_modified_date: Option<DateTime>,
}
A key-signing key (KSK) is a complex type that represents a public/private key pair. The private key is used to generate a digital signature for the zone signing key (ZSK). The public key is stored in the DNS and is used to authenticate the ZSK. A KSK is always associated with a hosted zone; it cannot exist by itself.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

A string used to identify a key-signing key (KSK). Name can include numbers, letters, and underscores (_). Name must be unique for each key-signing key in the same hosted zone.

kms_arn: Option<String>

The Amazon resource name (ARN) used to identify the customer managed key in Key Management Service (KMS). The KmsArn must be unique for each key-signing key (KSK) in a single hosted zone.

You must configure the customer managed key as follows:

Status

Enabled

Key spec

ECC_NIST_P256

Key usage

Sign and verify

Key policy

The key policy must give permission for the following actions:

  • DescribeKey

  • GetPublicKey

  • Sign

The key policy must also include the Amazon Route 53 service in the principal for your account. Specify the following:

  • "Service": "dnssec-route53.amazonaws.com"

For more information about working with the customer managed key in KMS, see Key Management Service concepts.

flag: i32

An integer that specifies how the key is used. For key-signing key (KSK), this value is always 257.

signing_algorithm_mnemonic: Option<String>

A string used to represent the signing algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.1.

signing_algorithm_type: i32

An integer used to represent the signing algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.1.

digest_algorithm_mnemonic: Option<String>

A string used to represent the delegation signer digest algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.3.

digest_algorithm_type: i32

An integer used to represent the delegation signer digest algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.3.

key_tag: i32

An integer used to identify the DNSSEC record for the domain name. The process used to calculate the value is described in RFC-4034 Appendix B.

digest_value: Option<String>

A cryptographic digest of a DNSKEY resource record (RR). DNSKEY records are used to publish the public key that resolvers can use to verify DNSSEC signatures that are used to secure certain kinds of information provided by the DNS system.

public_key: Option<String>

The public key, represented as a Base64 encoding, as required by RFC-4034 Page 5.

ds_record: Option<String>

A string that represents a delegation signer (DS) record.

dnskey_record: Option<String>

A string that represents a DNSKEY record.

status: Option<String>

A string that represents the current key-signing key (KSK) status.

Status can have one of the following values:

ACTIVE

The KSK is being used for signing.

INACTIVE

The KSK is not being used for signing.

DELETING

The KSK is in the process of being deleted.

ACTION_NEEDED

There is a problem with the KSK that requires you to take action to resolve. For example, the customer managed key might have been deleted, or the permissions for the customer managed key might have been changed.

INTERNAL_FAILURE

There was an error during a request. Before you can continue to work with DNSSEC signing, including actions that involve this KSK, you must correct the problem. For example, you may need to activate or deactivate the KSK.

status_message: Option<String>

The status message provided for the following key-signing key (KSK) statuses: ACTION_NEEDED or INTERNAL_FAILURE. The status message includes information about what the problem might be and steps that you can take to correct the issue.

created_date: Option<DateTime>

The date when the key-signing key (KSK) was created.

last_modified_date: Option<DateTime>

The last time that the key-signing key (KSK) was changed.

Implementations

Source

impl KeySigningKey

pub fn name(&self) -> Option<&str>

A string used to identify a key-signing key (KSK). Name can include numbers, letters, and underscores (_). Name must be unique for each key-signing key in the same hosted zone.

pub fn kms_arn(&self) -> Option<&str>

The Amazon resource name (ARN) used to identify the customer managed key in Key Management Service (KMS). The KmsArn must be unique for each key-signing key (KSK) in a single hosted zone.

You must configure the customer managed key as follows:

Status

Enabled

Key spec

ECC_NIST_P256

Key usage

Sign and verify

Key policy

The key policy must give permission for the following actions:

  • DescribeKey

  • GetPublicKey

  • Sign

The key policy must also include the Amazon Route 53 service in the principal for your account. Specify the following:

  • "Service": "dnssec-route53.amazonaws.com"

For more information about working with the customer managed key in KMS, see Key Management Service concepts.

pub fn flag(&self) -> i32

An integer that specifies how the key is used. For key-signing key (KSK), this value is always 257.

pub fn signing_algorithm_mnemonic(&self) -> Option<&str>

A string used to represent the signing algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.1.

pub fn signing_algorithm_type(&self) -> i32

An integer used to represent the signing algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.1.

pub fn digest_algorithm_mnemonic(&self) -> Option<&str>

A string used to represent the delegation signer digest algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.3.

pub fn digest_algorithm_type(&self) -> i32

An integer used to represent the delegation signer digest algorithm. This value must follow the guidelines provided by RFC-8624 Section 3.3.

pub fn key_tag(&self) -> i32

An integer used to identify the DNSSEC record for the domain name. The process used to calculate the value is described in RFC-4034 Appendix B.

pub fn digest_value(&self) -> Option<&str>

A cryptographic digest of a DNSKEY resource record (RR). DNSKEY records are used to publish the public key that resolvers can use to verify DNSSEC signatures that are used to secure certain kinds of information provided by the DNS system.

pub fn public_key(&self) -> Option<&str>

The public key, represented as a Base64 encoding, as required by RFC-4034 Page 5.

pub fn ds_record(&self) -> Option<&str>

A string that represents a delegation signer (DS) record.

pub fn dnskey_record(&self) -> Option<&str>

A string that represents a DNSKEY record.

pub fn status(&self) -> Option<&str>

A string that represents the current key-signing key (KSK) status.

Status can have one of the following values:

ACTIVE

The KSK is being used for signing.

INACTIVE

The KSK is not being used for signing.

DELETING

The KSK is in the process of being deleted.

ACTION_NEEDED

There is a problem with the KSK that requires you to take action to resolve. For example, the customer managed key might have been deleted, or the permissions for the customer managed key might have been changed.

INTERNAL_FAILURE

There was an error during a request. Before you can continue to work with DNSSEC signing, including actions that involve this KSK, you must correct the problem. For example, you may need to activate or deactivate the KSK.

pub fn status_message(&self) -> Option<&str>

The status message provided for the following key-signing key (KSK) statuses: ACTION_NEEDED or INTERNAL_FAILURE. The status message includes information about what the problem might be and steps that you can take to correct the issue.

pub fn created_date(&self) -> Option<&DateTime>

The date when the key-signing key (KSK) was created.

pub fn last_modified_date(&self) -> Option<&DateTime>

The last time that the key-signing key (KSK) was changed.

Source

impl KeySigningKey

pub fn builder() -> KeySigningKeyBuilder

Creates a new builder-style object to manufacture KeySigningKey.